==> haskell-language-haskell-extract-0.2.4-16-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-language-haskell-extract.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 language-haskell-extract
version:              0.2.4
visibility:           public
id:                   language-haskell-extract-0.2.4-1V5YmXnXhs17579cqiiLnH
key:                  language-haskell-extract-0.2.4-1V5YmXnXhs17579cqiiLnH
license:              BSD-3-Clause
maintainer:           Oscar Finnsson
author:               Oscar Finnsson & Emil Nordling
stability:            stable
homepage:             http://github.com/finnsson/template-helper
synopsis:
    Module to automatically extract functions from the local code.

description:
    @language-haskell-extract@ contains some useful helper functions on top of Template Haskell.

    @functionExtractor@ extracts all functions after a regexp-pattern.

    > foo = "test"
    > boo = "testing"
    > bar = $(functionExtractor "oo$")

    will automagically extract the functions ending with @oo@ such as

    > bar = [("foo",foo), ("boo",boo)]

    This can be useful if you wish to extract all functions beginning with test (for a test-framework)
    or all functions beginning with wc (for a web service).

    @functionExtractorMap@ works like @functionsExtractor@ but applies a function over all function-pairs.

    This functions is useful if the common return type of the functions is a type class.

    Example:

    > secondTypeclassTest =
    >   do let expected = ["45", "88.8", "\"hej\""]
    >          actual = $(functionExtractorMap "^tc" [|\n f -> show f|] )
    >      expected @=? actual
    >
    > tcInt :: Integer
    > tcInt = 45
    >
    > tcDouble :: Double
    > tcDouble = 88.8
    >
    > tcString :: String
    > tcString = "hej"

category:             Template Haskell
abi:                  69694d8da19da64482d28afa1dc2dbef
exposed:              True
exposed-modules:      Language.Haskell.Extract
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/language-haskell-extract-0.2.4

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/language-haskell-extract-0.2.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-haskell-extract
hs-libraries:         HSlanguage-haskell-extract-0.2.4-1V5YmXnXhs17579cqiiLnH
depends:
    base-4.16.4.0 regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
    template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-language-haskell-extract/html/language-haskell-extract.haddock

haddock-html:         /usr/share/doc/haskell-language-haskell-extract/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-haskell-extract-0.2.4-19-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-language-haskell-extract.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-haskell-extract
version:              0.2.4
visibility:           public
id:                   language-haskell-extract-0.2.4-4pLiEAYeVxNEmKT0OrqKlp
key:                  language-haskell-extract-0.2.4-4pLiEAYeVxNEmKT0OrqKlp
license:              BSD-3-Clause
maintainer:           Oscar Finnsson
author:               Oscar Finnsson & Emil Nordling
stability:            stable
homepage:             http://github.com/finnsson/template-helper
synopsis:
    Module to automatically extract functions from the local code.

description:
    @language-haskell-extract@ contains some useful helper functions on top of Template Haskell.

    @functionExtractor@ extracts all functions after a regexp-pattern.

    > foo = "test"
    > boo = "testing"
    > bar = $(functionExtractor "oo$")

    will automagically extract the functions ending with @oo@ such as

    > bar = [("foo",foo), ("boo",boo)]

    This can be useful if you wish to extract all functions beginning with test (for a test-framework)
    or all functions beginning with wc (for a web service).

    @functionExtractorMap@ works like @functionsExtractor@ but applies a function over all function-pairs.

    This functions is useful if the common return type of the functions is a type class.

    Example:

    > secondTypeclassTest =
    >   do let expected = ["45", "88.8", "\"hej\""]
    >          actual = $(functionExtractorMap "^tc" [|\n f -> show f|] )
    >      expected @=? actual
    >
    > tcInt :: Integer
    > tcInt = 45
    >
    > tcDouble :: Double
    > tcDouble = 88.8
    >
    > tcString :: String
    > tcString = "hej"

category:             Template Haskell
abi:                  aae33d06a5aa730eb060b35da2d1d2e5
exposed:              True
exposed-modules:      Language.Haskell.Extract
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/language-haskell-extract-0.2.4

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/language-haskell-extract-0.2.4

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/language-haskell-extract-0.2.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-haskell-extract
hs-libraries:         HSlanguage-haskell-extract-0.2.4-4pLiEAYeVxNEmKT0OrqKlp
depends:
    base-4.17.2.1 regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-language-haskell-extract/html/language-haskell-extract.haddock

haddock-html:         /usr/share/doc/haskell-language-haskell-extract/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
